import { SeatersApi } from '../../seaters-api';
import { session } from './session-types';
import { IUpdatePasswordDTO } from '../../seaters-api/fan/fan';
export declare enum SESSION_STRATEGY {
    EXPIRE = 0,
    EXTEND = 1,
}
export declare class SessionService {
    private seatersApi;
    private currentFan;
    private sessionStrategy;
    private sessionToken;
    constructor(seatersApi: SeatersApi, sessionStrategy?: SESSION_STRATEGY);
    /**
     * Configure the given session to be used. This method is intended for transitional
     * phase where the SDK is not the one doing the login process (Seaters FanWebApp)
     *
     * @param session a valid session that is not expired
     * @param fan a valid fan object
     */
    configureSession(s: session.SessionToken, fan: session.Fan): void;
    /**
     * Manually configure the fan (in case the current fan was changed / retrieved externally)
     *
     * @param fan latest fan object
     */
    updateCurrentFan(fan: session.Fan): Promise<session.Fan>;
    /**
     * Update password
     *
     * @param fan latest fan object
     */
    updatePassword(data: IUpdatePasswordDTO): Promise<session.Fan>;
    /**
     * Log in using an email/password
     * Log in using an email/password
     *
     * @param email valid email or seaters username
     * @param password plain text password
     * @param mfaToken authenticator token
     */
    doEmailPasswordLogin(email: string, password: string, mfaToken?: string): Promise<session.Session>;
    /**
     * Log in using a stored token (long term validity)
     *
     * @param storedToken long term token
     * @param mfaToken authenticator token
     */
    doStoredTokenLogin(storedToken: string, mfaToken?: string): Promise<session.Session>;
    /**
     * @deprecated Use doOAuthCodeLoginV2 instead to retrieve the session
     * @param oauthProvider
     * @param code
     * @returns {Promise<TResult2|TResult1>}
     */
    doOAuthCodeLogin(oauthProvider: string, code: string): Promise<session.Fan>;
    doOAuthCodeLoginV2(oauthProvider: string, code: string): Promise<session.Session>;
    doVerifyOAuth(input: any): Promise<session.Session>;
    doLogout(): void;
    doEmailPasswordSignUp(email: string, password: string, firstname: string, lastname: string, language: string, redirect: string, fanGroupReference: string): Promise<session.Session>;
    doEmailSignUp(email: string, fanGroupId: string, language?: string, origin?: string): Promise<session.Session>;
    /**
     * Validate an email by providing a confirmation code
     *
     * @param email The email that you want to validate
     * @param code The code that validates the email
     * @returns a Promise that resolves with an updated fan or rejects with a VALIDATION_ERRORS
     * @see VALIDATION_ERRORS
     */
    doEmailValidation(email: string, code: string): Promise<session.Fan>;
    /**
     * Validate a phone number by providing a confirmation code
     *
     * @param phone The phone number that you want to validate
     * @param code The code that validates the email
     * @returns a Promise that resolves with an updated fan or rejects with a VALIDATION_ERRORS
     * @see VALIDATION_ERRORS
     */
    doMobilePhoneNumberValidation(phone: session.PhoneNumber, code: string): Promise<session.Fan>;
    /**
     * Reset the user password based on the email
     * @param email email address
     */
    doPasswordReset(email: string): Promise<any>;
    /**
     * Change the email associated to the current user
     * @param email new email address
     */
    doEmailReset(email: string): Promise<any>;
    checkStoredTokenValidity(authToken: session.StoredToken, applicationName: string, deviceId?: string, applicationId?: string): boolean;
    /**
     * Checks if there are any valid stored tokens and returns the first one. If there are none
     * it will create a new token and return this
     * @param applicationName the name of the application, e.g. "Seaters Embedded"
     * @param deviceId defaults to "SDK-device-<random UUID>"
     * @param applicationId defaults to "SDK-app-<random UUID>"
     */
    obtainStoredToken(applicationName: string, deviceId?: string, applicationId?: string): Promise<session.StoredToken>;
    whoami(): session.Fan;
    setSession(s: session.SessionToken): void;
    setCurrentFan(): Promise<session.Fan>;
    private waitUntilMillisBeforeSessionExpires(s, msBefore);
    private applyExpireSessionStrategy(s);
    private applyExtendSessionStrategy(s);
    private finishLogin(authSuccess);
    private doRefreshTokenLogin(refreshToken, mfaToken?);
}
